@@ -9,7 +9,7 @@ NULL
 #' @aliases geom_*sidelabel
 #' @return XLayer or YLayer object to be added to a ggplot object
 #' @export
-geom_xsidelabel <- ggside_layer_function(fun = geom_label, side = "x", force_missing = c("nudge_x","nudge_y","position"))
+geom_xsidelabel <- ggside_layer_function(fun = geom_label, side = "x", force_missing = c("nudge_x", "nudge_y", "position"), label.size = quote(lifecycle::deprecated()))
 
 #' @rdname ggside-ggproto-geoms
 #' @usage NULL
@@ -20,7 +20,7 @@ GeomXsidelabel <- ggside_geom("GeomXsidelabel", GeomLabel, "x")
 
 #' @rdname geom_xsidelabel
 #' @export
-geom_ysidelabel <- ggside_layer_function(fun = geom_label, side = "y", force_missing = c("nudge_x","nudge_y","position"))
+geom_ysidelabel <- ggside_layer_function(fun = geom_label, side = "y", force_missing = c("nudge_x", "nudge_y", "position"), label.size = quote(lifecycle::deprecated()))
 
 #' @rdname ggside-ggproto-geoms
 #' @usage NULL
